[libcxx-commits] [PATCH] D115194: [libc++] Fix atomic test for _BitInt

Louis Dionne via Phabricator via libcxx-commits libcxx-commits at lists.llvm.org
Mon Dec 6 15:16:07 PST 2021


ldionne created this revision.
ldionne added a reviewer: aaron.ballman.
ldionne requested review of this revision.
Herald added a project: libc++.
Herald added a subscriber: libcxx-commits.
Herald added a reviewer: libc++.

In 6c75ab5f66b4 <https://reviews.llvm.org/rG6c75ab5f66b403f7ca67e86aeed3a58abe10570b>, Clang deprecated _ExtInt in favor of _BitInt, which
made this test fail. This patch disables the test on older compilers
and uses the new _BitInt type instead.


Repository:
  rG LLVM Github Monorepo

https://reviews.llvm.org/D115194

Files:
  libcxx/test/libcxx/atomics/bit-int.verify.cpp
  libcxx/test/libcxx/atomics/ext-int.verify.cpp


Index: libcxx/test/libcxx/atomics/bit-int.verify.cpp
===================================================================
--- libcxx/test/libcxx/atomics/bit-int.verify.cpp
+++ libcxx/test/libcxx/atomics/bit-int.verify.cpp
@@ -8,11 +8,12 @@
 
 // <atomic>
 
 // Make sure that `std::atomic` doesn't work with `_ExtInt`. The intent is to
 // disable them for now until their behavior can be designed better later.
 // See https://reviews.llvm.org/D84049 for details.
 
-// UNSUPPORTED: apple-clang-12
+// UNSUPPORTED: apple-clang-12, apple-clang-13
+// UNSUPPORTED: clang-12, clang-13
 
 // UNSUPPORTED: c++03
 
@@ -20,8 +21,8 @@
 
 int main(int, char**)
 {
-  // expected-error at atomic:*1 {{_Atomic cannot be applied to integer type '_ExtInt(32)'}}
-  std::atomic<_ExtInt(32)> x(42);
+  // expected-error-re at atomic:*1 {{_Atomic cannot be applied to integer type '_BitInt(32)'}}
+  std::atomic<_BitInt(32)> x(42);
 
   return 0;
 }


-------------- next part --------------
@@ -8,11 +8,12 @@
 // <atomic>
 
-// Make sure that `std::atomic` doesn't work with `_ExtInt`. The intent is to
+// Make sure that `std::atomic` doesn't work with `_BitInt`. The intent is to
 // disable them for now until their behavior can be designed better later.
 // See https://reviews.llvm.org/D84049 for details.
A non-text attachment was scrubbed...
Name: D115194.392202.patch
Type: text/x-patch
Size: 1007 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/libcxx-commits/attachments/20211206/059b4663/attachment.bin>


More information about the libcxx-commits mailing list